## usage

```python
from xfile_selector.selector import XFileSelector

if __name__ == "__main__":
    selector = XFileSelector(select_file=True, is_multi_file=True)
    files = selector.select_files()
    if files:
        for f in files:
            print(f)

```